@@ -4,7 +4,7 @@ from typing import Union
 import fastapi
 import fastapi.responses
 
-from souswift_core import dtos
+from souswift_core import models
 from souswift_core.exc import exceptions
 
 _Exception = Union[exceptions.APIError, exceptions.DatabaseError]
@@ -13,7 +13,7 @@ _Exception = Union[exceptions.APIError, exceptions.DatabaseError]
 def _api_error_handler(request: fastapi.Request, exc: exceptions.APIError):
     exc_response = exc.response()
     return fastapi.responses.UJSONResponse(
-        dtos.BaseError(
+        models.BaseError(
             title=type(exc).__name__.lower(),
             path=request.url.path,
             status=exc_response.status_code,
@@ -28,7 +28,7 @@ def _database_error_handler(
 ):
     exc_response = exc.response()
     return fastapi.responses.UJSONResponse(
-        dtos.BaseError(
+        models.BaseError(
             title=type(exc).__name__.lower(),
             path=request.url.path,
             status=exc_response.status_code,
@@ -41,7 +41,7 @@ def _database_error_handler(
 def _base_exception_handler(request: fastapi.Request, exc: Exception):
     status = http.HTTPStatus.INTERNAL_SERVER_ERROR
     return fastapi.responses.UJSONResponse(
-        dtos.BaseError(
+        models.BaseError(
             title='exception',
             path=request.url.path,
             status=status,
