@@ -6,7 +6,7 @@ from typing import Callable, TypeVar
 import pydantic
 from typing_extensions import ParamSpec
 
-from souswift_core.dtos import Model
+from souswift_core.models import Model
 
 T = TypeVar('T')
 P = ParamSpec('P')
